\NeedsTeXFormat{LaTeX2e}[2018/01/01]
\ProvidesClass{jamcm}[2018/01/01 JAMCM Format Class]
\LoadClass[11pt,a4paper,twoside]{article}
\RequirePackage{fancyhdr}
\RequirePackage[top=28mm,left=40mm,right=40mm, bottom=64mm, showframe=false]{geometry}

\RequirePackage[labelsep=period, skip=5pt, font=footnotesize, justification=centering]{caption}
\RequirePackage[thmmarks]{ntheorem}
%\RequirePackage{txfonts}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{mathptmx}
\RequirePackage{graphicx}
\RequirePackage{cite}

\ProcessOptions


\renewcommand{\figurename}{Fig.}
\renewcommand{\tablename}{Table}
\everymath{\displaystyle}

\RequirePackage{setspace}
\singlespacing
\nonfrenchspacing
\setlength{\parskip}{0cm}
\setlength{\parindent}{0.5cm}

\newcounter{question}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                    Submission information                      %%
%%                      Inserted by editor                           %%
%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand     {\firstpage}     [1] {\def\@thefirstpage{#1}}
\newcommand     {\volume}        [1] {\def\@thevolume{#1}}
\newcommand     {\issue}           [1] {\def\@theissue{#1}}
\renewcommand  {\year}            [1] {\def\@theyear{#1}}
\newcommand     {\pages}          [1] {\def\@thepages{#1}}
\renewcommand  {\title}             [1] {\def\@thetitle{#1}}
\newcommand     {\titleheader}  [1] {\def\@thetitleheader{#1}}
\newcommand     {\authors}       [1] {\def\@theauthors{#1}}
\newcommand     {\authorsheader} [1] {\def\@theauthorsheader{#1}}
\newcommand     {\affiliations}   [1] {\def\@theaffiliations{#1}}
\newcommand     {\emails}          [1] {\def\@theemails{#1}}
\newcommand     {\doi}               [1] {\def\@thedoi{#1}}
\newcommand     {\keywords}     [1] {\def\@thekeywords{#1}}
\newcommand     {\msc}              [1] {\def\@themsc{#1}}
\newcommand     {\datereceived}    [1] {\def\@thedatereceived{#1}}
\newcommand     {\dateaccepted}   [1] {\def\@thedateaccepted{#1}}
%----------------------------------------ntheorem.std-------------------------------------------------
\theoremnumbering{arabic}
\theoremstyle{plain}
\RequirePackage{latexsym}
\theoremsymbol{\ensuremath{_\Box}}
\theorembodyfont{\itshape}
\theoremheaderfont{\normalfont\bfseries}
\theoremseparator{}
\newtheorem{Theorem}{Theorem}
\newtheorem{theorem}{Theorem}
\newtheorem{Proposition}{Proposition}
\newtheorem{proposition}{Proposition}
\newtheorem{Lemma}{Lemma}
\newtheorem{lemma}{Lemma}
\newtheorem{Corollary}{Corollary}
\newtheorem{corollary}{Corollary}

\theorembodyfont{\upshape}
\newtheorem{Example}{Example}
\newtheorem{example}{Example}
\newtheorem{Remark}{Remark}
\newtheorem{remark}{Remark}
\newtheorem{Definition}{Definition}
\newtheorem{definition}{Definition}

\theoremstyle{nonumberplain}
\theoremheaderfont{\scshape}
\theorembodyfont{\normalfont}
\theoremsymbol{\ensuremath{_\blacksquare}}

\newtheorem{Proof}{Proof}
\newtheorem{proof}{Proof}
\qedsymbol{\ensuremath{_\blacksquare}}
\theoremclass{LaTeX}



%-------------------------------------------sections----------------------------------------------
\setcounter{section}{0}
\renewcommand{\thesection}{\arabic{section}}


\renewcommand\section{%
\@startsection%
	{section}{1}{0pt}    % name, level, indent
	{22pt}%		% beforeskip
	{12pt}%		% afterskip
	{\fontsize{12pt}{14pt}\selectfont \bf }%
}%

\setcounter{subsection}{0}
\renewcommand{\subsection}[1]{\stepcounter{subsection}\vspace{12pt}\par{\noindent \bf \thesubsection . \, #1}\vspace{0pt}\newline\indent}
\setcounter{subsubsection}{0}
\renewcommand{\subsubsection}[1]{\stepcounter{subsubsection}\vspace{22pt}\par{\noindent \bf \thesubsubsection . \, #1}\vspace{0pt}\newline\indent}
 
\renewcommand{\@seccntformat}[1]{\csname the#1\endcsname.\, }

%--------------------------------------titlepage---------------------------------------------------------------


\AtBeginDocument{
\setcounter{section}{0}
\setcounter{subsection}{0}
\setcounter{subsubsection}{0}
\setcounter{equation}{0}
\setcounter{footnote}{0}
\setcounter{theorem}{0}
\setcounter{theorem}{0}
\setcounter{lemma}{0}
\setcounter{proposition}{0}
\setcounter{corollary}{0}
\setcounter{example}{0}
\setcounter{remark}{0}
\setcounter{definition}{0}
\setcounter{question}{0}
\setcounter{assumption}{0}

\setlength{\abovedisplayshortskip}{9pt}
\setlength{\belowdisplayshortskip}{9pt}
\setlength{\abovedisplayskip}{9pt}
\setlength{\belowdisplayskip}{9pt}
\setlength{\headsep}{3.8mm}
%\setlength{\headheight}{4mm}
\setlength{\footskip}{4mm}

\setlength{\topmargin}{2.6mm}
%\setlength{\topskip}{0mm}

\thispagestyle{empty}
{
\vspace*{-11.9mm}
\par{
 {
 \noindent
\hspace{0mm} \hfill 
  \includegraphics[width=12.19mm]{logo_jamcm.png} \hfill \hspace{0.05mm}
 \parbox[b]{11.5cm}{ \fontsize{8pt}{10pt}\selectfont %
\centering Journal of Applied Mathematics and Computational Mechanics \@theyear, \@thevolume(\@theissue),  \@thepages 
\vspace{0.4mm}
\hrule 
\vspace{0.8mm}
www.amcm.pcz.pl \hfill p-ISSN 2299-9965\\
DOI: \@thedoi \hfill  e-ISSN 2353-0588\vspace{0.3mm}}\vspace{0.1mm}
\hrule}
  \centering
  \vspace*{5.3mm}
  \vspace{12pt}
  \fontsize{12pt}{14pt}\selectfont\textbf{\MakeUppercase{\@thetitle}} \\
  \vspace{36pt}
  \fontsize{10pt}{11.5pt}\selectfont\textbf{\textit{\@theauthors}} \\
  \vspace{6pt}
  \fontsize{9pt}{10.5pt}\selectfont\textit{\@theaffiliations} \\
  \fontsize{9pt}{10.5pt}\selectfont\textit{\@theemails} \\
  \vspace{6pt}
  \fontsize{9pt}{10.5pt}\selectfont Received: \@thedatereceived;  Accepted: \@thedateaccepted \\
  \vspace{18pt}
}
}
}

\AtEndDocument{
}

\fancypagestyle{plain}
{}

\fancypagestyle{jamcm_fancy}
{
\fancyhf{}
\fancyhead[CO]{\fontsize{8pt}{10pt}\selectfont \@thetitleheader\hspace{6mm}}
\fancyhead[CE]{\fontsize{8pt}{10pt}\selectfont \hspace{6mm}\@theauthorsheader}
\fancyhead[RO,LE]{\fontsize{10pt}{10pt}\selectfont \thepage}
\fancyfoot[L]{}
\fancyfoot[C]{}
\fancyfoot[R]{}
}

\fancyfoot{}

%-------------------------------------------abstract----------------------------------------------------------
\renewenvironment{abstract} 
{\fontsize{10}{11.8}\selectfont \noindent \begin{minipage}{\textwidth} \textbf{Abstract.}}
{\\ \\ \textit{\textbf{MSC 2010:} \@themsc} \\ \textit{\textbf{Keywords:} 
\@thekeywords }  \vspace{12pt} \end{minipage}}

%---------------------------------------theorem style-----------------------------------------------------
\newtheoremstyle{com}%
  {\vspace{2mm}\item[\hskip\labelsep \theorem@headerfont ##1\ ##2\theorem@separator]}%
  {\vspace{2mm}\item[\hskip\labelsep \theorem@headerfont ##1\ ##2\ (##3)\theorem@separator]}

\theoremheaderfont{\scshape}
\theoremstyle{com}
\theorembodyfont{\it}
%\renewtheorem{theorem}{Theorem}[section]
%\renewtheorem{lemma}[theorem]{Lemma}
%\renewtheorem{proposition}[theorem]{Proposition}
\newtheorem{fact}[theorem]{Fact}
%\renewtheorem{corollary}[theorem]{Corollary}
\theorembodyfont{\rm}
%\renewtheorem{example}[theorem]{Example}
%\renewtheorem{remark}[theorem]{Remark}
%\renewtheorem{definition}[theorem]{Definition }
\newtheorem{question}[theorem]{Question}
%\newtheorem{examples}[theorem]{Examples}
\newtheorem{assumption}{Assumption}


%---------------------------------------acknowledgements -----------------------------------------------------
\newenvironment{acknowledgement}
{{\bf Acknowledgement.}}{}


%-----------------------------------------pagestyles----------------------------------------------------




\renewenvironment{thebibliography}[1]
{
	\section*{References}
	  \fontsize{9pt}{11pt}\selectfont
             \list{\small\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}
			\setlength{\itemsep}{2pt}
			\setlength{\parsep}{0pt}
}
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}  



\endinput
